pub struct CustomAttributes { /* private fields */ }Expand description
A collection of custom attributes for a type, field, or variant.
These attributes can be created with the Reflect derive macro, or with
CustomAttributesBuilder.
Attributes are stored by their TypeId.
Because of this, there can only be one attribute per type.
Example
use core::ops::RangeInclusive;
#[derive(Reflect)]
struct Slider {
#[reflect(@RangeInclusive::<f32>::new(0.0, 1.0))]
value: f32
}
let TypeInfo::Struct(info) = <Slider as Typed>::type_info() else {
panic!("expected struct info");
};
let range = info.field("value").unwrap().get_attribute::<RangeInclusive<f32>>().unwrap();
assert_eq!(0.0..=1.0, *range);Implementations
Sourceimpl CustomAttributes
impl CustomAttributes
Sourcepub fn contains<T>(&self) -> boolwhere
T: Reflect,
pub fn contains<T>(&self) -> boolwhere
T: Reflect,
Returns true if this collection contains a custom attribute of the specified type.
Sourcepub fn contains_by_id(&self, id: TypeId) -> bool
pub fn contains_by_id(&self, id: TypeId) -> bool
Returns true if this collection contains a custom attribute with the specified TypeId.
Sourcepub fn get_by_id(&self, id: TypeId) -> Option<&(dyn Reflect + 'static)>
pub fn get_by_id(&self, id: TypeId) -> Option<&(dyn Reflect + 'static)>
Gets a custom attribute by its TypeId.